# Perry Bot

[![Documentation Status](https://readthedocs.org/projects/perry-bot/badge/?version=develop)](https://perry-bot.readthedocs.io/en/develop/?badge=develop)
[![CodeFactor](https://www.codefactor.io/repository/github/shunnkou/perry-bot/badge)](https://www.codefactor.io/repository/github/shunnkou/perry-bot)
[![DeepSource](https://deepsource.io/gh/shunnkou/perry-bot.svg/?label=active+issues)](https://deepsource.io/gh/shunnkou/perry-bot/?ref=repository-badge)
[![DeepSource](https://deepsource.io/gh/shunnkou/perry-bot.svg/?label=resolved+issues)](https://deepsource.io/gh/shunnkou/perry-bot/?ref=repository-badge)

A self-care bot.

* Free software: BSD license
* Documentation: https://perry-bot.readthedocs.io.

# Attention: this project is still heavily under development!


___


## Features
* CLI and GUI
* Tracker
  * Water tracker
  * Mood tracker
  * Habit tracker
    * Daily, weekly, bi-weekly, monthly, and yearly habits
* Visualize your tracked data
* Local data storage in a sqlite database.
* [You feel like sh*t's](https://youfeellikeshit.com/) interactive self-care



___

# Credits
This package was created based on a modified
[audreyr/cookiecutter-pypackage](https://github.com/audreyfeldroy/cookiecutter-pypackage)
project template using [Cookiecutter](https://github.com/cookiecutter/cookiecutter).
